from datetime import datetime


class Bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'


class CndPrint:
    separator = "#|#"
    colors = {
        'e': Bcolors.FAIL,  # Error
        'v': Bcolors.WARNING,  # Event
        'd': Bcolors.OKBLUE,  # display (default)
        's': Bcolors.OKGREEN,  # Success (default)
        'c': Bcolors.OKCYAN,  # Cyan (nothing special, just different color)
    }
    states = ['trace', 'log', 'info']

    def __init__(self, level="Info", uuid=None, silent_mode=False):
        self.level_index = CndPrint.states.index(level.lower())
        self.uuid = uuid
        self.silent_mode = silent_mode
        for state in CndPrint.states:
            for color in CndPrint.colors:
                setattr(CndPrint, f"{state}_{color}", self.make_method("log", color, state))

    def __build_message(self, message):
        now = datetime.now()
        dt_string = now.strftime("%d/%m/%Y %H:%M:%S")
        uuid = ""
        if self.uuid is not None:
            uuid = "{uuid}{separator}".format(separator=self.separator, uuid=self.uuid)
        full_message = "{uuid}{date}{separator}{message}".format(separator=self.separator, uuid=uuid, date=dt_string, message=message)
        return full_message

    def __colored_message(self, message, color_set, level):
        if CndPrint.states.index(level) < self.level_index:
            return False
        if self.silent_mode is True:
            return True
        print(CndPrint.colors[color_set] + self.__build_message(message) + Bcolors.ENDC)
        return True

    def make_method(self, name, level, state):
        def _method(self, message):
            return self.__colored_message(message, level, state)
        return _method



from setuptools import setup, find_packages
from cndprint.__version__ import __version__

setup(name='cndprint',
    version=__version__,
    description="The definitive tools to print pretty error log message",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent'
    ],
    keywords='',
    author='Denis FABIEN',
    author_email='denis.fabien@changendevops.com',
    url='https://changendevops.com',
    license='MIT/X11',
    packages=find_packages(exclude=['ez_setup', 'examples', 'spec', 'spec.*']),
    include_package_data=True,
    package_data={'cndprint': ['VERSION']},
    zip_safe=False,
    project_urls={
        "Documentation": "https://changendevops.com",
        "Source": "https://gitlab.com/changendevops/cndversion",
    },
)